@@ -8,7 +8,8 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_batch._jsii
+import aws_cdk.aws_apigateway._jsii
+import aws_cdk.aws_autoscaling._jsii
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codepipeline._jsii
 import aws_cdk.aws_ec2._jsii
@@ -17,6 +18,7 @@ import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kinesis._jsii
 import aws_cdk.aws_kinesisfirehose._jsii
+import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_sns._jsii
@@ -29,9 +31,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-events-targets",
-    "1.78.0",
+    "1.147.0",
     __name__[0:-6],
-    "aws-events-targets@1.78.0.jsii.tgz",
+    "aws-events-targets@1.147.0.jsii.tgz",
 )
 
 __all__ = [
